**To delete a game session queue**

The following ``delete-game-session-queue`` example deletes a specified game session queue. ::

    aws gamelift delete-game-session-queue \
        --name MegaFrogRace-NA 

This command produces no output.
